@@ -13,8 +13,7 @@ def prod_session_runner():
 
 @pytest.fixture
 def test_content_image(image_factory, test_image):
-    # 300 x 400 image
-    return image_factory.from_disk(test_image('canoe_water.jpg'), preprocess=True)
+    return image_factory.from_disk(test_image('canoe_water.jpg'))
 
 
 def test_session_runner_behaviour(prod_session_runner, test_content_image):
